Learn R Programming

faersquarterlydata (version 1.2.0)

estimate_chisq: Estimate Chi-Squared test with yates correction

Description

Estimate Chi-Squared test with yates correction

Usage

estimate_chisq(n11, n10, n01, n00)

Value

list with Chi-squared statistic and p-value

Arguments

n11

Number of events of interest within the group of interest

n10

Number of events of interest from all groups

n01

Number of all events within the group of interest

n00

Number of all events from all groups

Examples

Run this code
estimate_chisq(n11 = 20, n10 = 10, n01 = 200, n00 = 200)

Run the code above in your browser using DataLab