Learn R Programming

faersquarterlydata (version 1.2.0)

estimate_infoc: Estimate Information Component

Description

Estimate Information Component

Usage

estimate_infoc(n11, n10, n01, n00)

Value

List with Information Component estimate and its 0.95 IC

Arguments

n11

Number of events of interest within the group of interest

n10

Number of events of interest from all groups

n01

Number of all events within the group of interest

n00

Number of all events from all groups

Examples

Run this code
estimate_infoc(n11 = 20, n10 = 10, n01 = 200, n00 = 200)

Run the code above in your browser using DataLab