tibble with the event of interest counts, group of interest counts and the respective estimated measures of association
(ROR and its IC, PRR and its IC, Information Component and Chi-squared statisti with Yates correction.
Arguments
tabular_faers_data
FAERS tabular format. Output of function retrieve_faersxml or retrieve_faersxml_all
group_of_interest_col
a string, specifying the group of interest.
Must me a column name of `tabular_faers_data`, and this columns should only contain two unique values.
group_of_interest_ref
a string, specifying the group of interest reference. Must me a value from the group of interest column.
rename_vector
optional. named vector to rename the group of interest, in order to show up in a
event_of_interest_col
a string, specifying the event of interest. Must me a column name of `tabular_faers_data`.
...
arguments passed to `estimate_ror` like `ic_range`.