get_duplicate_caseids: Get duplicated caseIDs

View source: R/read_func_ascii.R

get_duplicate_caseidsR Documentation

Get duplicated caseIDs

Description

Retrieve the duplicated caseIDs to remove from the analysis.

Usage

get_duplicate_caseids(duplicates_dir = NULL)

Arguments

duplicates_dir

directory path where the text files with the duplicates information are.

Value

an integer vector with all the caseids to be removed


faersquarterlydata documentation built on Feb. 28, 2026, 1:07 a.m.