Read ASCII files from a directory, removing the duplicates.
retrieve_faersascii(
ascii_dir,
cache_path = NULL,
drug_indication_pattern = NULL,
drug_pattern = NULL,
primary_suspect = TRUE,
...
)A list with binded tibbles retrieved from files.
directory path where ascii files are
(optional) a string. Must have a ".Rdata" extension to save the read tabular formats in each loop.
(optional) a string.filter ADRs with a specific drug indication pattern (**stringr** sintax)
(optional) a string. filter ADRs with a specific drug name pattern (**stringr** sintax)
(optional) a string.
directory with duplicate information to be passed to get_duplicate_caseids