powered by
Estimate Chi-Squared test with yates correction
estimate_chisq(n11, n10, n01, n00)
list with Chi-squared statistic and p-value
Number of events of interest within the group of interest
Number of events of interest from all groups
Number of all events within the group of interest
Number of all events from all groups
estimate_chisq(n11 = 20, n10 = 10, n01 = 200, n00 = 200)
Run the code above in your browser using DataLab