powered by
Estimate Information Component
estimate_infoc(n11, n10, n01, n00)
List with Information Component estimate and its 0.95 IC
Number of events of interest within the group of interest
Number of events of interest from all groups
Number of all events within the group of interest
Number of all events from all groups
estimate_infoc(n11 = 20, n10 = 10, n01 = 200, n00 = 200)
Run the code above in your browser using DataLab